==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Na voljo je nova različica {version}. Oglejte si več podrobnosti o nadgradnji.",
    "Channel updated" : "Kanal je posodobljen",
    "Update notifications" : "Obvestila o posodobitvah",
    "The update server could not be reached since %d days to check for new updates." : "Vzpostavitev povezave s strežnikom za posodobitve ni mogoče že %d dni.",
    "Please check the Nextcloud and server log files for errors." : "Preverite strežniške in sistemske dnevnike za napake.",
    "Update to %1$s is available." : "Na voljo je posodobitev na %1$s.",
    "Update for %1$s to version %2$s is available." : "Na voljo je posodobitev %1$s na različico %2$s.",
    "Update for {app} to version %s is available." : "Na voljo je posodobitev programa {app} na različico %s.",
    "Update notification" : "Obvestilo o posodobitvi",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Pokaže obvestila o posodobitvah okolja Nextcloud in omogoča prijavo SSO za posodabljalnik.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Različica, ki je trenutno v uporabi, ni več vzdrževana. Priporočljivo je čim prej posodobiti okolje!",
    "Apps missing updates" : "Manjkajoče programske posodobitve",
    "View in store" : "Pokaži v trgovini",
    "Apps with available updates" : "Programi z objavljenimi posodobitvami",
    "Open updater" : "Odpri posodabljalnik",
    "Download now" : "Prejmi takoj",
    "What's new?" : "Kaj je novega?",
    "The update check is not yet finished. Please refresh the page." : "Preverjanje za posodobitve še ni končano. Osvežite stran za ponovno vzpostavitev seje.",
    "Your version is up to date." : "Nameščena je najnovejša različica.",
    "A non-default update server is in use to be checked for updates:" : "Za posodobitev bo uporabljen neprivzet strežnik:",
    "Update channel:" : "Posodobi kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Nadgradnja na višjo različico je vedno mogoča, ne pa tudi povrnitev na predhodno, bolj stabilno.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Po vsaki novi objavi je lahko tudi daljši časovni zamik, preden se posodobitev pojavi v sistemu. Nove različice objavljamo v časovnih razmikih in včasih kakšno tudi preskočimo, če prvi uporabniki zaznajo težave ali napake.",
    "Notify members of the following groups about available updates:" : "Člani navedenih skupin, ki so obveščeni o posodobitvah:",
    "Only notification for app updates are available." : "Na voljo so le obvestila za posodobitve programov.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izbran kanal za posodobitve onemogoča obvestila s strežnika.",
    "The selected update channel does not support updates of the server." : "Izbran kanal za posodobitve ne omogoča posodobitev stražnika.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Na voljo je nova različica: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Nazadnje preverjeno {lastCheckedDate}",
    "Checking apps for compatible updates" : "Poteka preverjanje za skladne posodobitve ...",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prepričajte se, da v datoteki config.php možnost <samp>appstoreenabled</samp> ni nastavljena na vrednost napak – false.",
    "<strong>All</strong> apps have an update for this version available" : "Za <strong>vse nameščene programe</strong> je na voljo podprta posodobitev.",
    "View changelog" : "Ogled Dnevnika sprememb",
    "Enterprise" : "Poslovno",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Za poslovno uporabo. Na voljo so najnovejši popravki programov in manjše posodobitve, ne pa tudi takojšnja nadgradnja sistema na naslednjo večjo različico. Ta posodobitev je na voljo šele po daljšem in podrobnejšem preizkušanju sistema. Ta kanal je na voljo le naročnikom, ki uporabljajo paket Nextcloud Enterprise.",
    "Stable" : "Stabilno",
    "Beta" : "Preizkusno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Na voljo je nova različica {version}. Oglejte si več podrobnosti o nadgradnji.",
    "Channel updated" : "Kanal je posodobljen",
    "Update notifications" : "Obvestila o posodobitvah",
    "The update server could not be reached since %d days to check for new updates." : "Vzpostavitev povezave s strežnikom za posodobitve ni mogoče že %d dni.",
    "Please check the Nextcloud and server log files for errors." : "Preverite strežniške in sistemske dnevnike za napake.",
    "Update to %1$s is available." : "Na voljo je posodobitev na %1$s.",
    "Update for %1$s to version %2$s is available." : "Na voljo je posodobitev %1$s na različico %2$s.",
    "Update for {app} to version %s is available." : "Na voljo je posodobitev programa {app} na različico %s.",
    "Update notification" : "Obvestilo o posodobitvi",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Pokaže obvestila o posodobitvah okolja Nextcloud in omogoča prijavo SSO za posodabljalnik.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Različica, ki je trenutno v uporabi, ni več vzdrževana. Priporočljivo je čim prej posodobiti okolje!",
    "Apps missing updates" : "Manjkajoče programske posodobitve",
    "View in store" : "Pokaži v trgovini",
    "Apps with available updates" : "Programi z objavljenimi posodobitvami",
    "Open updater" : "Odpri posodabljalnik",
    "Download now" : "Prejmi takoj",
    "What's new?" : "Kaj je novega?",
    "The update check is not yet finished. Please refresh the page." : "Preverjanje za posodobitve še ni končano. Osvežite stran za ponovno vzpostavitev seje.",
    "Your version is up to date." : "Nameščena je najnovejša različica.",
    "A non-default update server is in use to be checked for updates:" : "Za posodobitev bo uporabljen neprivzet strežnik:",
    "Update channel:" : "Posodobi kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Nadgradnja na višjo različico je vedno mogoča, ne pa tudi povrnitev na predhodno, bolj stabilno.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Po vsaki novi objavi je lahko tudi daljši časovni zamik, preden se posodobitev pojavi v sistemu. Nove različice objavljamo v časovnih razmikih in včasih kakšno tudi preskočimo, če prvi uporabniki zaznajo težave, ali napake.",
    "Notify members of the following groups about available updates:" : "Člani navedenih skupin, ki so obveščeni o posodobitvah:",
    "Only notification for app updates are available." : "Na voljo so le obvestila za posodobitve programov.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izbran kanal za posodobitve onemogoča obvestila s strežnika.",
    "The selected update channel does not support updates of the server." : "Izbran kanal za posodobitve ne omogoča posodobitev stražnika.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Na voljo je nova različica: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Nazadnje preverjeno {lastCheckedDate}",
    "Checking apps for compatible updates" : "Poteka preverjanje za skladne posodobitve ...",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prepričajte se, da v datoteki config.php možnost <samp>appstoreenabled</samp> ni nastavljena na vrednost napak – false.",
    "<strong>All</strong> apps have an update for this version available" : "Za <strong>vse nameščene programe</strong> je na voljo podprta posodobitev.",
    "View changelog" : "Ogled Dnevnika sprememb",
    "Enterprise" : "Poslovno",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Za poslovno uporabo. Na voljo so najnovejši popravki programov in manjše posodobitve, ne pa tudi takojšnja nadgradnja sistema na naslednjo večjo različico. Ta posodobitev je na voljo šele po daljšem in podrobnejšem preizkušanju sistema. Ta kanal je na voljo le naročnikom, ki uporabljajo paket Nextcloud Enterprise.",
    "Stable" : "Stabilno",
    "Beta" : "Preizkusno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
